HashState

Struct HashState 

pub struct HashState {
    pub version: u64,
    pub hash: [u8; 128],
    pub index_value_map: HashMap<String, Vec<u8>>,
}

Fields

version: u64hash: [u8; 128]index_value_map: HashMap<String, Vec<u8>>

Implementations

Source

impl HashState

pub fn update_hash<F>( &mut self, mutations: &[SyncdMutation], get_prev_set_value_mac: F, ) -> (HashUpdateResult, Result<()>)
where F: FnMut(&[u8], usize) -> Result<Option<Vec<u8>>>,

pub fn update_hash_from_records(&mut self, records: &[SyncdRecord])

Update hash state from snapshot records directly (avoids cloning into SyncdMutation).

This is an optimized version for snapshots where all operations are SET and there are no previous values to look up.

pub fn generate_snapshot_mac(&self, name: &str, key: &[u8]) -> Vec<u8>